@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,11 +11,6 @@
 #include "akregatorconfig.h"
 #include "articleviewerwebenginepage.h"
 #include "webengine/urlhandlerwebenginemanager.h"
-#include <kpimtextedit/kpimtextedit-texttospeech.h>
-#include <kwidgetsaddons_version.h>
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-#include <KPIMTextEdit/TextToSpeech>
-#endif
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
 #include <WebEngineViewer/WebEngineManageScript>
@@ -311,11 +306,9 @@ void ArticleViewerWebEngine::slotWebHitFinished(const WebEngineViewer::WebHitTes
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("tab_unmute")));
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("find_in_messages")));
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-    if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
-        popup.addSeparator();
-        popup.addAction(ActionManager::getInstance()->action(QStringLiteral("speak_text")));
-    }
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    popup.addSeparator();
+    popup.addAction(ActionManager::getInstance()->action(QStringLiteral("speak_text")));
 #endif
     popup.exec(mapToGlobal(result.pos()));
 }
@@ -381,20 +374,12 @@ void ArticleViewerWebEngine::disableIntroduction()
 {
     KGuiItem yesButton(i18n("Disable"));
     KGuiItem noButton(i18n("Keep Enabled"));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (KMessageBox::questionTwoActions(this,
-#else
-    if (KMessageBox::questionYesNo(this,
-#endif
                                         i18n("Are you sure you want to disable this introduction page?"),
                                         i18n("Disable Introduction Page"),
                                         yesButton,
                                         noButton)
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         == KMessageBox::PrimaryAction) {
-#else
-        == KMessageBox::Yes) {
-#endif
         Settings::self()->setDisableIntroduction(true);
         Settings::self()->save();
     }
@@ -424,13 +409,8 @@ void ArticleViewerWebEngine::forwardMouseReleaseEvent(QMouseEvent *event)
 
 bool ArticleViewerWebEngine::urlIsAMalwareButContinue()
 {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (KMessageBox::SecondaryAction
         == KMessageBox::questionTwoActions(this,
-#else
-    if (KMessageBox::No
-        == KMessageBox::warningYesNo(this,
-#endif
                                            i18n("This web site is a malware, do you want to continue to show it?"),
                                            i18n("Malware"),
                                            KStandardGuiItem::cont(),
